# Against all Odds

[![Build Status](https://travis-ci.com/S1M0N38/aao.svg?branch=master)](https://travis-ci.com/S1M0N38/aao)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/840c1f6d7dba42e9b6fcbe8973008dcc)](https://www.codacy.com/app/S1M0N38/aao?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=S1M0N38/aao&amp;utm_campaign=Badge_Grade)

Aganistallodds project aim to offert an environment where everyone can test his betting strategy on real odds.
You can get the odds in two way: through **manual scraping** or using the **api**.

## Installation

to install all againstallodds open your terminal and type

```
pip install aao
```

If you plan to use the manual scrape you must also install chrome and chromedrivers as well. Search on google how to do on your operative system.

## Docs

Avaiable at https://s1m0n38.github.io/aao/
